@@ -278,7 +278,6 @@ def test__run_query():
     assert len(execution_updates) == 3  # one update per API response
     for line in execution_updates:
         assert re.match("Query executing: .*s", line)
-    assert re.match("Query complete after .*s", updates[-1])
 
 
 def test__run_query_dry_run_without_errors_is_silent():
@@ -597,7 +596,7 @@ def test_bigquery_magic_with_bqstorage_from_argument(monkeypatch):
     query_job_mock.to_dataframe.assert_called_once_with(
         bqstorage_client=bqstorage_instance_mock,
         create_bqstorage_client=mock.ANY,
-        progress_bar_type="tqdm",
+        progress_bar_type="tqdm_notebook",
     )
 
     assert isinstance(return_value, pandas.DataFrame)
@@ -641,7 +640,7 @@ def test_bigquery_magic_with_rest_client_requested(monkeypatch):
         query_job_mock.to_dataframe.assert_called_once_with(
             bqstorage_client=None,
             create_bqstorage_client=False,
-            progress_bar_type="tqdm",
+            progress_bar_type="tqdm_notebook",
         )
 
     assert isinstance(return_value, pandas.DataFrame)
